# Generated by Django 3.2 on 2021-04-21 15:52

import django.contrib.postgres.fields.jsonb
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("data", "0033_auto_20210421_1538"),
    ]

    operations = [
        migrations.AddField(
            model_name="organization",
            name="other_names",
            field=django.contrib.postgres.fields.jsonb.JSONField(
                blank=True, default=list
            ),
        ),
    ]
