# Generated by Django 3.2.2 on 2021-08-02 17:52

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("data", "0035_auto_20210422_1926"),
    ]

    operations = [
        migrations.AddField(
            model_name="jurisdiction",
            name="latest_bill_update",
            field=models.DateTimeField(default=datetime.date(2021, 1, 1)),
        ),
        migrations.AddField(
            model_name="jurisdiction",
            name="latest_people_update",
            field=models.DateTimeField(default=datetime.date(2021, 1, 1)),
        ),
    ]
