# Generated by Django 3.0.5 on 2020-08-04 16:54

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [("data", "0012_person_current_role")]

    operations = [migrations.RemoveField(model_name="person", name="current_state")]
