# Generated by Django 3.0.5 on 2020-09-23 13:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("data", "0025_auto_20200914_1216"),
    ]

    operations = [
        migrations.AddField(
            model_name="billdocument",
            name="classification",
            field=models.CharField(
                blank=True,
                choices=[
                    ("", "Unknown"),
                    ("fiscal-note", "Fiscal Note"),
                    ("committee-report", "Committee Report"),
                    ("summary", "Summary"),
                    ("digest", "Digest"),
                    ("veto-message", "Veto Message"),
                    ("analysis", "Analysis"),
                    ("law", "Law"),
                ],
                max_length=100,
            ),
        ),
        migrations.AddField(
            model_name="billversion",
            name="classification",
            field=models.CharField(
                blank=True,
                choices=[
                    ("", "Unknown"),
                    ("filed", "Filed"),
                    ("introduced", "Introduced"),
                    ("amendment", "Amendment"),
                    ("substituted", "Substituted"),
                    ("enrolled", "Enrolled"),
                    ("became-law", "Became Law"),
                ],
                max_length=100,
            ),
        ),
        migrations.AlterField(
            model_name="jurisdiction",
            name="classification",
            field=models.CharField(
                choices=[("state", "State"), ("municipality", "Municipality")],
                db_index=True,
                default="state",
                help_text="The type of Jurisdiction being defined.",
                max_length=50,
            ),
        ),
        migrations.AlterField(
            model_name="organization",
            name="classification",
            field=models.CharField(
                blank=True,
                choices=[
                    ("legislature", "Legislature"),
                    ("executive", "Executive"),
                    ("upper", "Upper Chamber"),
                    ("lower", "Lower Chamber"),
                    ("party", "Party"),
                    ("committee", "Committee"),
                    ("government", "Government"),
                ],
                help_text="The type of Organization being defined.",
                max_length=100,
            ),
        ),
    ]
