# Generated by Django 3.2.2 on 2021-10-07 20:29

from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ("data", "0040_auto_20210920_2347"),
    ]

    operations = [
        migrations.CreateModel(
            name="PersonOffice",
            fields=[
                (
                    "id",
                    models.UUIDField(
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                (
                    "classification",
                    models.CharField(
                        choices=[
                            ("district", "District Office"),
                            ("capitol", "Capitol Office"),
                            ("primary", "Primary Office"),
                        ],
                        max_length=20,
                    ),
                ),
                ("address", models.CharField(blank=True, default="", max_length=300)),
                ("voice", models.CharField(blank=True, default="", max_length=30)),
                ("fax", models.CharField(blank=True, default="", max_length=30)),
                ("name", models.CharField(blank=True, default="", max_length=200)),
                (
                    "person",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="offices",
                        to="data.person",
                    ),
                ),
            ],
            options={
                "db_table": "openstates_personoffice",
            },
        ),
    ]
